/*********************************************************************
 *                  Flowcode CAL RTCC File
 *
 * File: PIC16BIT_CAL_RTC.c
 *
 * (c) 2017 Matrix Multimedia Ltd.
 * http://www.matrixmultimedia.com
 *
 * Software License Agreement
 *
 * The software supplied herewith by Matrix Multimedia Ltd (the
 * Company) for its Flowcode graphical programming language is
 * intended and supplied to you, the Companys customer, for use
 * solely and exclusively on the Company's products. The software
 * is owned by the Company, and is protected under applicable
 * copyright laws. All rights are reserved. Any use in violation
 * of the foregoing restrictions may subject the user to criminal
 * sanctions under applicable laws, as well as to civil liability
 * for the breach of the terms and conditions of this licence.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Changelog:
 *
 *  date  | by | description
 * -------+----+-----------------------------------------------------
 * 080517 | BR | Created
 */


CALFUNCTION(void, FC_CAL_RTC_Init_, (void));

CALFUNCTION(void, FC_CAL_RTC_SetSec_, (MX_UINT8 Data));
CALFUNCTION(void, FC_CAL_RTC_SetMin_, (MX_UINT8 Data));
CALFUNCTION(void, FC_CAL_RTC_SetHour_, (MX_UINT8 Data));
CALFUNCTION(void, FC_CAL_RTC_SetWeekDay_, (MX_UINT8 Data));
CALFUNCTION(void, FC_CAL_RTC_SetDay_, (MX_UINT8 Data));
CALFUNCTION(void, FC_CAL_RTC_SetMonth_, (MX_UINT8 Data));
CALFUNCTION(void, FC_CAL_RTC_SetYear_, (MX_UINT8 Data));

CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetSec_, (void));
CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetMin_, (void));
CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetHour_, (void));
CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetWeekDay_, (void));
CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetDay_, (void));
CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetMonth_, (void));
CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetYear_, (void));



// RTC Type 1 Supported Devices ************************************************************
// 24FJ128GA310 Family
// *******************************************************************************************/

#ifdef MX_RTC_TYPE_1


	CALFUNCTION(void, FC_CAL_RTC_Init_, (void))
	{
		RCFGCALbits.RTCEN = 0;					//Disable RTCC

		//Enable RTCC Register Writes.
		asm volatile("push w7");
		asm volatile("push w8");
		asm volatile("disi #5");
		asm volatile("mov #0x55, w7");
		asm volatile("mov w7, _NVMKEY");
		asm volatile("mov #0xAA, w8");
		asm volatile("mov w8, _NVMKEY");
		asm volatile("bset _RCFGCAL, #13"); 	//set the RTCWREN bit
		asm volatile("pop w8");
		asm volatile("pop w7");

		#ifdef _RTCPWC_RTCLK_POSITION 			//Not all devices have a configurable clock
			RTCPWCbits.RTCLK = MX_RTC_CLOCK;	//Set the RTCC Clock
		#endif

		RCFGCALbits.RTCEN = 1;					//Enable RTCC
	}


	//Write Functions

	CALFUNCTION(void, FC_CAL_RTC_SetSec_, (MX_UINT8 Data))
	{
		RCFGCALbits.RTCPTR = 0;		//Min/Sec Selection
		RTCVAL &= 0xFF00;			//Clear Month Bits
		RTCVAL |= Data;				//Assign Data Bits
	}

	CALFUNCTION(void, FC_CAL_RTC_SetMin_, (MX_UINT8 Data))
	{
		RCFGCALbits.RTCPTR = 0;		//Min/Sec Selection
		RTCVAL &= 0x00FF;			//Clear Month Bits
		RTCVAL |= Data << 8;		//Assign Data Bits
	}

	CALFUNCTION(void, FC_CAL_RTC_SetHour_, (MX_UINT8 Data))
	{
		RCFGCALbits.RTCPTR = 1;		//Weekday/Hour Selection
		RTCVAL &= 0xFF00;			//Clear Month Bits
		RTCVAL |= Data;				//Assign Data Bits
	}

	CALFUNCTION(void, FC_CAL_RTC_SetWeekDay_, (MX_UINT8 Data))
	{
		RCFGCALbits.RTCPTR = 1;		//Weekday/Hour Selection
		RTCVAL &= 0x00FF;			//Clear Month Bits
		RTCVAL |= Data << 8;		//Assign Data Bits
	}

	CALFUNCTION(void, FC_CAL_RTC_SetDay_, (MX_UINT8 Data))
	{
		RCFGCALbits.RTCPTR = 2;		//Month/Day Selection
		RTCVAL &= 0xFF00;			//Clear Month Bits
		RTCVAL |= Data;				//Assign Data Bits
	}

	CALFUNCTION(void, FC_CAL_RTC_SetMonth_, (MX_UINT8 Data))
	{
		RCFGCALbits.RTCPTR = 2;		//Month/Day Selection
		RTCVAL &= 0x00FF;			//Clear Month Bits
		RTCVAL |= Data << 8;		//Assign Data Bits
	}

	CALFUNCTION(void, FC_CAL_RTC_SetYear_, (MX_UINT8 Data))
	{
		RCFGCALbits.RTCPTR = 3;		//Year Selection
		RTCVAL &= 0xFF00;			//Clear Month Bits
		RTCVAL |= Data;				//Assign Data Bits
	}


	//Read Functions

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetSec_, (void))
	{
		MX_UINT8 retval;
		RCFGCALbits.RTCPTR = 0;		//Min/Sec Selection
		retval = RTCVAL;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetMin_, (void))
	{
		MX_UINT8 retval;
		RCFGCALbits.RTCPTR = 0;		//Min/Sec Selection
		retval = RTCVAL >> 8;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetHour_, (void))
	{
		MX_UINT8 retval;
		RCFGCALbits.RTCPTR = 1;		//Weekday/Hour Selection
		retval = RTCVAL;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetWeekDay_, (void))
	{
		MX_UINT8 retval;
		RCFGCALbits.RTCPTR = 1;		//Weekday/Hour Selection
		retval = RTCVAL >> 8;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetDay_, (void))
	{
		MX_UINT8 retval;
		RCFGCALbits.RTCPTR = 2;		//Month/Day Selection
		retval = RTCVAL;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetMonth_, (void))
	{
		MX_UINT8 retval;
		RCFGCALbits.RTCPTR = 2;		//Month/Day Selection
		retval = RTCVAL >> 8;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetYear_, (void))
	{
		MX_UINT8 retval;
		RCFGCALbits.RTCPTR = 3;		//Year Selection
		retval = RTCVAL;
		return (retval);
	}


#endif


// RTC Type 2 Supported Devices ************************************************************
// 24FJ256GA412 Family
// *******************************************************************************************/

#ifdef MX_RTC_TYPE_2


	CALFUNCTION(void, FC_CAL_RTC_Init_, (void))
	{
		RTCCON1Lbits.RTCEN = 0;					//Disable RTCC

		//Enable RTCC Register Writes.
		asm volatile ("DISI #6");
		asm volatile ("MOV #NVMKEY, W1");
		asm volatile ("MOV #0x55, W2");
		asm volatile ("MOV W2, [W1]");
		asm volatile ("MOV #0xAA, W3");
		asm volatile ("MOV W3, [W1]");
		asm volatile ("BCLR RTCCON1L, #WRLOCK");

		RTCCON2Lbits.CLKSEL = MX_RTC_CLOCK;		//Set the RTCC Clock
		RTCCON2Lbits.PS = MX_RTC_PRESCALER;		//Set the RTCC Prescaler
		RTCCON2Lbits.FDIV = MX_RTC_FRACDIV;		//Set the RTCC Fractional Divider
		RTCCON2H = MX_RTC_DIVIDER;				//Set the RTCC Clock Divider 16-bit Value

		RTCCON1Lbits.RTCEN = 1;					//Enable RTCC
	}


	//Write Functions

	CALFUNCTION(void, FC_CAL_RTC_SetSec_, (MX_UINT8 Data))
	{
		TIMEL &= 0x00FF;
		TIMEL |= Data << 8;
	}

	CALFUNCTION(void, FC_CAL_RTC_SetMin_, (MX_UINT8 Data))
	{
		TIMEH &= 0xFF00;
		TIMEH |= Data;
	}

	CALFUNCTION(void, FC_CAL_RTC_SetHour_, (MX_UINT8 Data))
	{
		TIMEH &= 0x00FF;
		TIMEH |= Data << 8;
	}

	CALFUNCTION(void, FC_CAL_RTC_SetWeekDay_, (MX_UINT8 Data))
	{
		DATEL &= 0xFF00;
		DATEL |= Data;
	}

	CALFUNCTION(void, FC_CAL_RTC_SetDay_, (MX_UINT8 Data))
	{
		DATEL &= 0x00FF;
		DATEL |= Data << 8;
	}

	CALFUNCTION(void, FC_CAL_RTC_SetMonth_, (MX_UINT8 Data))
	{
		DATEH &= 0xFF00;
		DATEH |= Data;
	}

	CALFUNCTION(void, FC_CAL_RTC_SetYear_, (MX_UINT8 Data))
	{
		DATEH &= 0x00FF;
		DATEH |= Data << 8;
	}


	//Read Functions

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetSec_, (void))
	{
		MX_UINT8 retval;
		retval = TIMEL >> 8;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetMin_, (void))
	{
		MX_UINT8 retval;
		retval = TIMEL >> 8;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetHour_, (void))
	{
		MX_UINT8 retval;
		retval = TIMEH >> 8;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetWeekDay_, (void))
	{
		MX_UINT8 retval;
		retval = DATEL;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetDay_, (void))
	{
		MX_UINT8 retval;
		retval = DATEL >> 8;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetMonth_, (void))
	{
		MX_UINT8 retval;
		retval = DATEH;
		return (retval);
	}

	CALFUNCTION(MX_UINT8, FC_CAL_RTC_GetYear_, (void))
	{
		MX_UINT8 retval;
		retval = DATEH >> 8;
		return (retval);
	}


#endif



